public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Zhu, Yonghong" <yonghong.zhu@intel.com>
To: Gary Lin <glin@suse.com>,
	"edk2-devel@lists.01.org" <edk2-devel@lists.01.org>
Cc: "Gao, Liming" <liming.gao@intel.com>,
	"Zhu, Yonghong" <yonghong.zhu@intel.com>
Subject: Re: [PATCH 02/33] BaseTools: Fix typos in comments and variables
Date: Wed, 19 Oct 2016 07:36:49 +0000	[thread overview]
Message-ID: <B9726D6DCCFB8B4CA276A9169B02216D4F3AC8AE@SHSMSX103.ccr.corp.intel.com> (raw)
In-Reply-To: <20161019070138.16424-3-glin@suse.com>

Reviewed-by: Yonghong Zhu <yonghong.zhu@intel.com> 

Best Regards,
Zhu Yonghong


-----Original Message-----
From: Gary Lin [mailto:glin@suse.com] 
Sent: Wednesday, October 19, 2016 3:01 PM
To: edk2-devel@lists.01.org
Cc: Zhu, Yonghong <yonghong.zhu@intel.com>; Gao, Liming <liming.gao@intel.com>
Subject: [PATCH 02/33] BaseTools: Fix typos in comments and variables

- Pacakge -> Package
- outputed -> outputted
- successull -> successfully
- Libary -> Library
- Pointion -> Position
- paramter -> parameter

Cc: Yonghong Zhu <yonghong.zhu@intel.com>
Cc: Liming Gao <liming.gao@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Gary Lin <glin@suse.com>
---
 BaseTools/Source/C/Common/Decompress.c           |  6 +++---
 BaseTools/Source/C/Common/Decompress.h           |  4 ++--
 BaseTools/Source/C/Common/ParseInf.c             |  2 +-
 BaseTools/Source/C/EfiRom/EfiRom.c               |  4 ++--
 BaseTools/Source/C/GenCrc32/GenCrc32.c           |  2 +-
 BaseTools/Source/C/GenFfs/GenFfs.c               |  2 +-
 BaseTools/Source/C/GenFw/GenFw.c                 |  8 ++++----
 BaseTools/Source/C/GenPage/GenPage.c             |  2 +-
 BaseTools/Source/C/GenSec/GenSec.c               | 14 +++++++-------
 BaseTools/Source/C/Split/Split.c                 |  6 +++---
 BaseTools/Source/C/TianoCompress/TianoCompress.h |  4 ++--  BaseTools/Source/C/VfrCompile/Pccts/dlg/dlg_p.c  |  2 +-
 12 files changed, 28 insertions(+), 28 deletions(-)

diff --git a/BaseTools/Source/C/Common/Decompress.c b/BaseTools/Source/C/Common/Decompress.c
index 48578ea..d266b6f 100644
--- a/BaseTools/Source/C/Common/Decompress.c
+++ b/BaseTools/Source/C/Common/Decompress.c
@@ -675,7 +675,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -810,7 +810,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
@@ -840,7 +840,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 --*/
diff --git a/BaseTools/Source/C/Common/Decompress.h b/BaseTools/Source/C/Common/Decompress.h
index 004804c..2899ed5 100644
--- a/BaseTools/Source/C/Common/Decompress.h
+++ b/BaseTools/Source/C/Common/Decompress.h
@@ -39,7 +39,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 **/
@@ -97,7 +97,7 @@ Arguments:
 
 Returns:
 
-  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successull retrieved.
+  EFI_SUCCESS           - The size of destination buffer and the size of scratch buffer are successfully retrieved.
   EFI_INVALID_PARAMETER - The source data is corrupted
 
 **/
diff --git a/BaseTools/Source/C/Common/ParseInf.c b/BaseTools/Source/C/Common/ParseInf.c
index 9e85a88..0a204c8 100644
--- a/BaseTools/Source/C/Common/ParseInf.c
+++ b/BaseTools/Source/C/Common/ParseInf.c
@@ -506,7 +506,7 @@ Returns:
   Index = 0;
   
   //
-  // Check input paramter
+  // Check input parameter
   //
   if (AsciiString == NULL || ReturnValue == NULL) {
     return EFI_INVALID_PARAMETER;
diff --git a/BaseTools/Source/C/EfiRom/EfiRom.c b/BaseTools/Source/C/EfiRom/EfiRom.c
index 7a57912..e2bd289 100644
--- a/BaseTools/Source/C/EfiRom/EfiRom.c
+++ b/BaseTools/Source/C/EfiRom/EfiRom.c
@@ -120,7 +120,7 @@ Returns:
   for (FList = mOptions.FileList; FList != NULL; FList = FList->Next) {
     if (stricmp (mOptions.OutFileName, FList->FileName) == 0) {
       Status = STATUS_ERROR;
-      Error (NULL, 0, 1002, "Invalid input paramter", "Input and output file names must be different - %s = %s.", FList->FileName, mOptions.OutFileName);
+      Error (NULL, 0, 1002, "Invalid input parameter", "Input and 
+ output file names must be different - %s = %s.", FList->FileName, 
+ mOptions.OutFileName);
       goto BailOut;
     }
   }
@@ -168,7 +168,7 @@ Returns:
   // Check total size
   //
   if (TotalSize > MAX_OPTION_ROM_SIZE) {
-    Error (NULL, 0, 2000, "Invalid paramter", "Option ROM image size exceeds limit of 0x%X bytes.", MAX_OPTION_ROM_SIZE);
+    Error (NULL, 0, 2000, "Invalid parameter", "Option ROM image size 
+ exceeds limit of 0x%X bytes.", MAX_OPTION_ROM_SIZE);
     Status = STATUS_ERROR;
   }
 
diff --git a/BaseTools/Source/C/GenCrc32/GenCrc32.c b/BaseTools/Source/C/GenCrc32/GenCrc32.c
index ad8cf57..f4d129e 100644
--- a/BaseTools/Source/C/GenCrc32/GenCrc32.c
+++ b/BaseTools/Source/C/GenCrc32/GenCrc32.c
@@ -248,7 +248,7 @@ Returns:
   VerboseMsg ("%s tool start.", UTILITY_NAME);
   
   //
-  // Check Input paramters
+  // Check Input parameters
   //
   if (FileAction == CRC32_NULL) {
     Error (NULL, 0, 1001, "Missing option", "either the encode or the decode option must be specified!"); diff --git a/BaseTools/Source/C/GenFfs/GenFfs.c b/BaseTools/Source/C/GenFfs/GenFfs.c
index 433b608..9a738cb 100644
--- a/BaseTools/Source/C/GenFfs/GenFfs.c
+++ b/BaseTools/Source/C/GenFfs/GenFfs.c
@@ -739,7 +739,7 @@ Returns:
   VerboseMsg ("%s tool start.", UTILITY_NAME);
 
   //
-  // Check the complete input paramters.
+  // Check the complete input parameters.
   //
   if (FfsFiletype == EFI_FV_FILETYPE_ALL) {
     Error (NULL, 0, 1001, "Missing option", "filetype"); diff --git a/BaseTools/Source/C/GenFw/GenFw.c b/BaseTools/Source/C/GenFw/GenFw.c
index 03bfaa1..b62756a 100644
--- a/BaseTools/Source/C/GenFw/GenFw.c
+++ b/BaseTools/Source/C/GenFw/GenFw.c
@@ -1093,7 +1093,7 @@ Returns:
   EFI_HII_PACKAGE_LIST_HEADER      HiiPackageListHeader;
   EFI_HII_PACKAGE_HEADER           HiiPackageHeader;
   EFI_IFR_FORM_SET                 IfrFormSet;
-  UINT8                            NumberOfFormPacakge;
+  UINT8                            NumberOfFormPackage;
   EFI_HII_PACKAGE_HEADER           EndPackage;
   UINT32                           HiiSectionHeaderSize;
   UINT8                            *HiiSectionHeader;
@@ -1140,7 +1140,7 @@ Returns:
   KeepExceptionTableFlag = FALSE;
   KeepOptionalHeaderFlag = FALSE;
   KeepZeroPendingFlag    = FALSE;
-  NumberOfFormPacakge    = 0;
+  NumberOfFormPackage    = 0;
   HiiPackageListBuffer   = NULL;
   HiiPackageDataPointer  = NULL;
   EndPackage.Length      = sizeof (EFI_HII_PACKAGE_HEADER);
@@ -1642,7 +1642,7 @@ Returns:
           fread (&IfrFormSet, 1, sizeof (IfrFormSet), fpIn);
           memcpy (&HiiPackageListGuid, &IfrFormSet.Guid, sizeof (EFI_GUID));
         }
-        NumberOfFormPacakge ++;
+        NumberOfFormPackage ++;
       }
       HiiPackageListHeader.PackageLength += FileLength;
       fclose (fpIn);
@@ -1651,7 +1651,7 @@ Returns:
     //
     // Check whether hii packages are valid
     //
-    if (NumberOfFormPacakge > 1) {
+    if (NumberOfFormPackage > 1) {
       Error (NULL, 0, 3000, "Invalid", "The input hii packages contains more than one hii form package");
       goto Finish;
     }
diff --git a/BaseTools/Source/C/GenPage/GenPage.c b/BaseTools/Source/C/GenPage/GenPage.c
index fb829e6..ef69823 100644
--- a/BaseTools/Source/C/GenPage/GenPage.c
+++ b/BaseTools/Source/C/GenPage/GenPage.c
@@ -401,7 +401,7 @@ main (
     }
     
     //
-    // Don't recognize the paramter.
+    // Don't recognize the parameter.
     //
     InputFile = argv[0];
     argc--;
diff --git a/BaseTools/Source/C/GenSec/GenSec.c b/BaseTools/Source/C/GenSec/GenSec.c
index 20b2a10..d2bf102 100644
--- a/BaseTools/Source/C/GenSec/GenSec.c
+++ b/BaseTools/Source/C/GenSec/GenSec.c
@@ -267,10 +267,10 @@ Returns:
   STATUS                    Status;
 
   if (InputFileNum > 1) {
-    Error (NULL, 0, 2000, "Invalid paramter", "more than one input file specified");
+    Error (NULL, 0, 2000, "Invalid parameter", "more than one input 
+ file specified");
     return STATUS_ERROR;
   } else if (InputFileNum < 1) {
-    Error (NULL, 0, 2000, "Invalid paramter", "no input file specified");
+    Error (NULL, 0, 2000, "Invalid parameter", "no input file 
+ specified");
     return STATUS_ERROR;
   }
   //
@@ -296,7 +296,7 @@ Returns:
   // Size must fit in 3 bytes
   //
   //if (TotalLength >= MAX_SECTION_SIZE) {
-  //  Error (NULL, 0, 2000, "Invalid paramter", "%s file size (0x%X) exceeds section size limit(%uM).", InputFileName[0], (unsigned) TotalLength, MAX_SECTION_SIZE>>20);
+  //  Error (NULL, 0, 2000, "Invalid parameter", "%s file size (0x%X) 
+ exceeds section size limit(%uM).", InputFileName[0], (unsigned) 
+ TotalLength, MAX_SECTION_SIZE>>20);
   //  goto Done;
   //}
   HeaderLength = sizeof (EFI_COMMON_SECTION_HEADER); @@ -436,12 +436,12 @@ Returns:
   UINT32                     HeaderSize;
 
   if (InputFileNum < 1) {
-    Error (NULL, 0, 2000, "Invalid paramter", "must specify at least one input file");
+    Error (NULL, 0, 2000, "Invalid parameter", "must specify at least 
+ one input file");
     return EFI_INVALID_PARAMETER;
   }
 
   if (BufferLength == NULL) {
-    Error (NULL, 0, 2000, "Invalid paramter", "BufferLength can't be NULL");
+    Error (NULL, 0, 2000, "Invalid parameter", "BufferLength can't be 
+ NULL");
     return EFI_INVALID_PARAMETER;
   }
 
@@ -698,7 +698,7 @@ Returns:
     break;
 
   default:
-    Error (NULL, 0, 2000, "Invalid paramter", "unknown compression type");
+    Error (NULL, 0, 2000, "Invalid parameter", "unknown compression 
+ type");
     free (FileBuffer);
     return EFI_ABORTED;
   }
@@ -737,7 +737,7 @@ Returns:
             "the original section size is %d bytes and the compressed section size is %u bytes", (unsigned) InputLength, (unsigned) CompressedLength);
 
   //if (TotalLength >= MAX_SECTION_SIZE) {
-  //  Error (NULL, 0, 2000, "Invalid paramter", "The size of all files exceeds section size limit(%uM).", MAX_SECTION_SIZE>>20);
+  //  Error (NULL, 0, 2000, "Invalid parameter", "The size of all files 
+ exceeds section size limit(%uM).", MAX_SECTION_SIZE>>20);
   //  if (FileBuffer != NULL) {
   //    free (FileBuffer);
   //  }
diff --git a/BaseTools/Source/C/TianoCompress/TianoCompress.h b/BaseTools/Source/C/TianoCompress/TianoCompress.h
index accbe2c..2971225 100644
--- a/BaseTools/Source/C/TianoCompress/TianoCompress.h
+++ b/BaseTools/Source/C/TianoCompress/TianoCompress.h
@@ -1,5 +1,5 @@
 /** @file
-  Internal include file for Tiano Decompress Libary.
+  Internal include file for Tiano Decompress Library.
 
   Copyright (c) 2006 - 2014, Intel Corporation. All rights reserved.<BR>
   This program and the accompanying materials @@ -361,7 +361,7 @@ DecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
diff --git a/BaseTools/Source/C/VfrCompile/Pccts/dlg/dlg_p.c b/BaseTools/Source/C/VfrCompile/Pccts/dlg/dlg_p.c
index e726ae3..af07c27 100644
--- a/BaseTools/Source/C/VfrCompile/Pccts/dlg/dlg_p.c
+++ b/BaseTools/Source/C/VfrCompile/Pccts/dlg/dlg_p.c
@@ -39,7 +39,7 @@ Fix for Borland C++ 4.x & 5.x compiling with ALL warnings enabled  #pragma warn -aus  /* unused assignment of 'xxx' */  #endif
 
-int	action_no = 0;	   /* keep track of actions outputed */
+int	action_no = 0;	   /* keep track of actions outputted */
 int	nfa_allocated = 0; /* keeps track of number of nfa nodes */
 nfa_node **nfa_array = NULL;/* root of binary tree that stores nfa array */
 nfa_node nfa_model_node;   /* model to initialize new nodes */
diff --git a/BaseTools/Source/C/Split/Split.c b/BaseTools/Source/C/Split/Split.c
index c6f547c..d723ed0 100644
--- a/BaseTools/Source/C/Split/Split.c
+++ b/BaseTools/Source/C/Split/Split.c
@@ -323,7 +323,7 @@ Returns:
       if (strlen(argv[0]) > 2) {
         Status = CountVerboseLevel (&argv[0][2], strlen(argv[0]) - 2, &VerboseLevel);
         if (EFI_ERROR (Status)) {
-          Error (NULL, 0, 0x1003, NULL, "%s is invaild paramter!", argv[0]);
+          Error (NULL, 0, 0x1003, NULL, "%s is invaild parameter!", 
+ argv[0]);
           return STATUS_ERROR;
         }
       }
@@ -344,9 +344,9 @@ Returns:
       continue;
     }
     //
     // Don't recognize the paramter.
     //
-    Error (NULL, 0, 0x1003, NULL, "%s is invaild paramter!", argv[0]);
+    Error (NULL, 0, 0x1003, NULL, "%s is invaild parameter!", argv[0]);
     return STATUS_ERROR;
   }
 
@@ -344,9 +344,9 @@ Returns:
     }
     //
-    // Don't recognize the paramter.
+    // Don't recognize the parameter.
     //
--
2.10.1



  parent reply	other threads:[~2016-10-19  7:36 UTC|newest]

Thread overview: 79+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-10-19  7:01 [PATCH 00/33] Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 01/33] ArmPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19 15:15     ` Laszlo Ersek
2016-10-19 15:33       ` Leif Lindholm
2016-10-19  7:01 ` [PATCH 02/33] BaseTools: Fix typos in comments and variables Gary Lin
2016-10-19  7:30   ` Gao, Liming
2016-10-19  7:36   ` Zhu, Yonghong [this message]
2016-10-19  7:01 ` [PATCH 03/33] CorebootPayloadPkg: Fix typos in comments Gary Lin
2016-10-26 18:50   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 04/33] CorebootModulePkg: " Gary Lin
2016-10-26 18:41   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 05/33] CryptoPkg: " Gary Lin
2016-10-26  3:00   ` Long, Qin
2016-10-19  7:01 ` [PATCH 06/33] DuetPkg: " Gary Lin
2016-10-19  7:46   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 07/33] EdkCompatibilityPkg: " Gary Lin
2016-10-19  8:19   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 08/33] EmulatorPkg: Fix typos in comments and variables Gary Lin
2016-10-19 20:37   ` Jordan Justen
2016-10-20  8:16     ` Laszlo Ersek
2016-10-19  7:01 ` [PATCH 09/33] EmbeddedPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19  7:01 ` [PATCH 10/33] IntelFrameworkModulePkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 11/33] IntelFrameworkPkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 12/33] IntelFspPkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 13/33] IntelFspWrapperPkg: " Gary Lin
2016-10-19  7:08   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 14/33] IntelFsp2Pkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:12   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 15/33] IntelFsp2WrapperPkg: Fix a typo in the comment Gary Lin
2016-10-19  7:07   ` Yao, Jiewen
2016-10-19  7:11   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 16/33] MdeModulePkg: BootManagerMenuApp: Fix typos in comments Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 17/33] MdeModulePkg/Bus: " Gary Lin
2016-10-19  7:01 ` [PATCH 18/33] MdeModulePkg/Core: " Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 19/33] MdeModulePkg/Include: " Gary Lin
2016-10-19  7:01 ` [PATCH 20/33] MdeModulePkg/Library: Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 21/33] MdeModulePkg/Universal: Fix typos in comments Gary Lin
2016-10-19  7:01 ` [PATCH 22/33] MdePkg: " Gary Lin
2016-10-19  8:21   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 23/33] NetworkPkg: " Gary Lin
2016-10-19  7:21   ` Fu, Siyuan
2016-10-26  0:53   ` Fu, Siyuan
2016-10-19  7:01 ` [PATCH 24/33] Nt32Pkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:50   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 25/33] OptionRomPkg: Fix typos in comments Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 26/33] OvmfPkg: " Gary Lin
2016-10-19  7:01 ` [PATCH 27/33] QuarkPlatformPkg: " Gary Lin
2016-10-25 20:53   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 28/33] QuarkSocPkg: " Gary Lin
2016-10-25 21:00   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 29/33] SecurityPkg: " Gary Lin
2016-10-27  1:29   ` Zhang, Chao B
2016-11-14  3:12   ` Zhang, Chao B
2016-11-14  4:03     ` Gary Lin
2016-11-14  6:24       ` Gao, Liming
2016-11-14  8:30         ` Gary Lin
2016-10-19  7:01 ` [PATCH 30/33] ShellPkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19 20:29     ` Carsey, Jaben
2016-10-20  1:55       ` Gary Lin
2016-10-19  7:01 ` [PATCH 31/33] SourceLevelDebugPkg: Fix typos in comments Gary Lin
2016-10-19  7:46   ` Wu, Hao A
2016-10-19  7:01 ` [PATCH 32/33] UefiCpuPkg: " Gary Lin
2016-10-20  1:58   ` Fan, Jeff
2016-10-20  2:08     ` Gary Lin
2016-10-20  2:45       ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 33/33] Vlv2TbltDevicePkg: " Gary Lin
2016-10-24  1:33   ` Wei, David
2016-10-19  7:28 ` [PATCH 00/33] Fix typos in comments and variables Zeng, Star
2016-10-19 14:50 ` Leif Lindholm

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=B9726D6DCCFB8B4CA276A9169B02216D4F3AC8AE@SHSMSX103.ccr.corp.intel.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox